@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 # type: ignore
 
-# Compiled with Coconut version 1.5.0-post_dev26 [Fish License]
+# Compiled with Coconut version 1.5.0-post_dev43 [Fish License]
 
 """Built-in Coconut utilities."""
 
@@ -21,9 +21,7 @@ if _coconut_sys.version_info < (3,):
         __slots__ = ()
         def __ne__(self, other):
             eq = self == other
-            if eq is _coconut.NotImplemented:
-                return eq
-            return not eq
+            return _coconut.NotImplemented if eq is _coconut.NotImplemented else not eq
     class int(_coconut_py_int):
         __slots__ = ()
         if hasattr(_coconut_py_int, "__doc__"):
@@ -97,7 +95,7 @@ if _coconut_sys.version_info < (3,):
         def __copy__(self):
             return self.__class__(*self._args)
         def __eq__(self, other):
-            return _coconut.isinstance(other, self.__class__) and self._args == other._args
+            return self.__class__ is other.__class__ and self._args == other._args
     from collections import Sequence as _coconut_Sequence
     _coconut_Sequence.register(range)
     from functools import wraps as _coconut_wraps
@@ -201,6 +199,14 @@ class _coconut(object):
             from backports.functools_lru_cache import lru_cache
             functools.lru_cache = lru_cache
         except ImportError: pass
+    if _coconut_sys.version_info < (3, 4):
+        try:
+            import trollius as asyncio
+        except ImportError:
+            class you_need_to_install_trollius: pass
+            asyncio = you_need_to_install_trollius()
+    else:
+        import asyncio
     if _coconut_sys.version_info < (3,):
         import cPickle as pickle
     else:
@@ -210,15 +216,15 @@ class _coconut(object):
         abc = collections
     else:
         import collections.abc as abc
-    if _coconut_sys.version_info >= (3, 6):
-        import typing
-    else:
+    if _coconut_sys.version_info < (3, 6):
         class typing(object):
             @staticmethod
             def NamedTuple(name, fields):
                 return _coconut.collections.namedtuple(name, [x for x, t in fields])
+    else:
+        import typing
     zip_longest = itertools.zip_longest if _coconut_sys.version_info >= (3,) else itertools.izip_longest
-    Ellipsis, NotImplemented, NotImplementedError, Exception, AttributeError, ImportError, IndexError, KeyError, NameError, TypeError, ValueError, StopIteration, RuntimeError, classmethod, dict, enumerate, filter, float, frozenset, getattr, hasattr, hash, id, int, isinstance, issubclass, iter, len, list, locals, map, min, max, next, object, print, property, range, reversed, set, slice, str, sum, super, tuple, type, vars, zip, repr, bytearray = Ellipsis, NotImplemented, NotImplementedError, Exception, AttributeError, ImportError, IndexError, KeyError, NameError, TypeError, ValueError, StopIteration, RuntimeError, classmethod, dict, enumerate, filter, float, frozenset, getattr, hasattr, hash, id, int, isinstance, issubclass, iter, len, list, locals, map, min, max, next, object, print, property, range, reversed, set, slice, str, sum, super, tuple, type, vars, zip, staticmethod(repr), bytearray
+    Ellipsis, NotImplemented, NotImplementedError, Exception, AttributeError, ImportError, IndexError, KeyError, NameError, TypeError, ValueError, StopIteration, RuntimeError, any, bytes, classmethod, dict, enumerate, filter, float, frozenset, getattr, hasattr, hash, id, int, isinstance, issubclass, iter, len, list, locals, map, min, max, next, object, print, property, range, reversed, set, slice, str, sum, super, tuple, type, vars, zip, repr, bytearray = Ellipsis, NotImplemented, NotImplementedError, Exception, AttributeError, ImportError, IndexError, KeyError, NameError, TypeError, ValueError, StopIteration, RuntimeError, any, bytes, classmethod, dict, enumerate, filter, float, frozenset, getattr, hasattr, hash, id, int, isinstance, issubclass, iter, len, list, locals, map, min, max, next, object, print, property, range, reversed, set, slice, str, sum, super, tuple, type, vars, zip, staticmethod(repr), bytearray
 _coconut_sentinel = _coconut.object()
 class MatchError(Exception):
     """Pattern-matching error. Has attributes .pattern, .value, and .message."""
@@ -350,15 +356,17 @@ def tee(iterable, n=2):
     return _coconut.itertools.tee(iterable, n)
 class reiterable(object):
     """Allows an iterator to be iterated over multiple times."""
-    __slots__ = ("iter",)
+    __slots__ = ("lock", "iter")
     def __new__(cls, iterable):
         if _coconut.isinstance(iterable, _coconut_reiterable):
             return iterable
         self = _coconut.object.__new__(cls)
+        self.lock = _coconut.threading.Lock()
         self.iter = iterable
         return self
     def get_new_iter(self):
-        self.iter, new_iter = _coconut_tee(self.iter)
+        with self.lock:
+            self.iter, new_iter = _coconut_tee(self.iter)
         return new_iter
     def __iter__(self):
         return _coconut.iter(self.get_new_iter())
@@ -431,7 +439,7 @@ class reversed(object):
     def __reduce__(self):
         return (self.__class__, (self.iter,))
     def __eq__(self, other):
-        return _coconut.isinstance(other, self.__class__) and self.iter == other.iter
+        return self.__class__ is other.__class__ and self.iter == other.iter
     def __contains__(self, elem):
         return elem in self.iter
     def count(self, elem):
@@ -518,7 +526,7 @@ class _coconut_base_parallel_concurrent_map(map):
 class parallel_map(_coconut_base_parallel_concurrent_map):
     """Multi-process implementation of map using concurrent.futures.
     Requires arguments to be pickleable. For multiple sequential calls,
-    use `with parallel_map.multiple_sequential_calls()`."""
+    use `with parallel_map.multiple_sequential_calls():`."""
     __slots__ = ()
     threadlocal_ns = _coconut.threading.local()
     @classmethod
@@ -530,7 +538,7 @@ class parallel_map(_coconut_base_parallel_concurrent_map):
 class concurrent_map(_coconut_base_parallel_concurrent_map):
     """Multi-thread implementation of map using concurrent.futures.
     For multiple sequential calls, use
-    `with concurrent_map.multiple_sequential_calls()`."""
+    `with concurrent_map.multiple_sequential_calls():`."""
     __slots__ = ()
     threadlocal_ns = _coconut.threading.local()
     @classmethod
@@ -562,29 +570,37 @@ class filter(_coconut.filter):
     def __fmap__(self, func):
         return _coconut_map(func, self)
 class zip(_coconut.zip):
-    __slots__ = ("iters",)
+    __slots__ = ("iters", "strict")
     if hasattr(_coconut.zip, "__doc__"):
         __doc__ = _coconut.zip.__doc__
-    def __new__(cls, *iterables):
+    def __new__(cls, *iterables, **kwargs):
         new_zip = _coconut.zip.__new__(cls, *iterables)
         new_zip.iters = iterables
+        new_zip.strict = kwargs.pop("strict", False)
+        if kwargs:
+            raise _coconut.TypeError("zip() got unexpected keyword arguments " + _coconut.repr(kwargs))
         return new_zip
     def __getitem__(self, index):
         if _coconut.isinstance(index, _coconut.slice):
-            return self.__class__(*(_coconut_igetitem(i, index) for i in self.iters))
+            return self.__class__(*(_coconut_igetitem(i, index) for i in self.iters), strict=self.strict)
         return _coconut.tuple(_coconut_igetitem(i, index) for i in self.iters)
     def __reversed__(self):
-        return self.__class__(*(_coconut_reversed(i) for i in self.iters))
+        return self.__class__(*(_coconut_reversed(i) for i in self.iters), strict=self.strict)
     def __len__(self):
         return _coconut.min(_coconut.len(i) for i in self.iters)
     def __repr__(self):
-        return "zip(%s)" % (", ".join((_coconut.repr(i) for i in self.iters)),)
+        return "zip(%s%s)" % (", ".join((_coconut.repr(i) for i in self.iters)), ", strict=True" if self.strict else "")
     def __reduce__(self):
-        return (self.__class__, self.iters)
+        return (self.__class__, self.iters, self.strict)
     def __reduce_ex__(self, _):
         return self.__reduce__()
+    def __setstate__(self, strict):
+        self.strict = strict
     def __iter__(self):
-        return _coconut.iter(_coconut.zip(*self.iters))
+        for items in _coconut.iter(_coconut.zip(*self.iters, strict=self.strict) if _coconut_sys.version_info >= (3, 10) else _coconut.zip_longest(*self.iters, fillvalue=_coconut_sentinel) if self.strict else _coconut.zip(*self.iters)):
+            if self.strict and _coconut_sys.version_info < (3, 10) and _coconut.any(x is _coconut_sentinel for x in items):
+                raise _coconut.ValueError("zip(..., strict=True) arguments have mismatched lengths")
+            yield items
     def __fmap__(self, func):
         return _coconut_map(func, self)
 class zip_longest(zip):
@@ -592,7 +608,7 @@ class zip_longest(zip):
     if hasattr(_coconut.zip_longest, "__doc__"):
         __doc__ = (_coconut.zip_longest).__doc__
     def __new__(cls, *iterables, **kwargs):
-        self = _coconut_zip.__new__(cls, *iterables)
+        self = _coconut_zip.__new__(cls, *iterables, strict=False)
         self.fillvalue = kwargs.pop("fillvalue", None)
         if kwargs:
             raise _coconut.TypeError("zip_longest() got unexpected keyword arguments " + _coconut.repr(kwargs))
@@ -620,7 +636,9 @@ class zip_longest(zip):
     def __repr__(self):
         return "zip_longest(%s, fillvalue=%s)" % (", ".join((_coconut.repr(i) for i in self.iters)), self.fillvalue)
     def __reduce__(self):
-        return (self.__class__, self.iters, {"fillvalue": fillvalue})
+        return (self.__class__, self.iters, self.fillvalue)
+    def __setstate__(self, fillvalue):
+        self.fillvalue = fillvalue
     def __iter__(self):
         return _coconut.iter(_coconut.zip_longest(*self.iters, fillvalue=self.fillvalue))
 class enumerate(_coconut.enumerate):
@@ -704,7 +722,7 @@ class count(object):
     def __copy__(self):
         return self.__class__(self.start, self.step)
     def __eq__(self, other):
-        return _coconut.isinstance(other, self.__class__) and self.start == other.start and self.step == other.step
+        return self.__class__ is other.__class__ and self.start == other.start and self.step == other.step
     def __fmap__(self, func):
         return _coconut_map(func, self)
 class groupsof(object):
@@ -777,7 +795,7 @@ class recursive_iterator(object):
             self.tee_store[key], to_return = _coconut_tee(it)
         return to_return
     def __repr__(self):
-        return "@recursive_iterator(" + _coconut.repr(self.func) + ")"
+        return "@recursive_iterator(%s)" % (_coconut.repr(self.func),)
     def __reduce__(self):
         return (self.__class__, (self.func,))
     def __get__(self, obj, objtype=None):
@@ -840,7 +858,7 @@ class _coconut_base_pattern_func(object):
                 pass
         return _coconut_tail_call(self.patterns[-1], *args, **kwargs)
     def __repr__(self):
-        return "addpattern(" + _coconut.repr(self.patterns[0]) + ")(*" + _coconut.repr(self.patterns[1:]) + ")"
+        return "addpattern(%s)(*%s)" % (_coconut.repr(self.patterns[0]), _coconut.repr(self.patterns[1:]))
     def __reduce__(self):
         return (self.__class__, _coconut.tuple(self.patterns))
     def __get__(self, obj, objtype=None):
@@ -904,7 +922,7 @@ class _coconut_partial(object):
                 args.append("?")
         for arg in self._stargs:
             args.append(_coconut.repr(arg))
-        return _coconut.repr(self.func) + "$(" + ", ".join(args) + ")"
+        return "%s$(%s)" % (_coconut.repr(self.func), ", ".join(args))
 def consume(iterable, keep_last=0):
     """consume(iterable, keep_last) fully exhausts iterable and return the last keep_last elements."""
     return _coconut.collections.deque(iterable, maxlen=keep_last)
@@ -949,7 +967,7 @@ def datamaker(*args, **kwargs):
     raise _coconut.NameError("deprecated feature 'datamaker' disabled by --strict compilation; use 'makedata' instead")
 def fmap(func, obj):
     """fmap(func, obj) creates a copy of obj with func applied to its contents.
-    Override by defining obj.__fmap__(func)."""
+    Override by defining obj.__fmap__(func). For numpy arrays, uses np.vectorize."""
     obj_fmap = _coconut.getattr(obj, "__fmap__", None)
     if obj_fmap is not None:
         try:
@@ -959,7 +977,7 @@ def fmap(func, obj):
         else:
             if result is not _coconut.NotImplemented:
                 return result
-    if obj.__class__.__module__ == "numpy":
+    if obj.__class__.__module__ in ("numpy", "pandas"):
         from numpy import vectorize
         return vectorize(func)(obj)
     return _coconut_makedata(obj.__class__, *(_coconut_starmap(func, obj.items()) if _coconut.isinstance(obj, _coconut.abc.Mapping) else _coconut_map(func, obj)))
@@ -979,11 +997,19 @@ class override(object):
     def __get__(self, obj, objtype=None):
         if obj is None:
             return self.func
-        if _coconut_sys.version_info >= (3,):
-            return _coconut.types.MethodType(self.func, obj)
-        else:
+        if _coconut_sys.version_info < (3,):
             return _coconut.types.MethodType(self.func, obj, objtype)
+        else:
+            return _coconut.types.MethodType(self.func, obj)
     def __set_name__(self, obj, name):
         if not _coconut.hasattr(_coconut.super(obj, obj), name):
             raise _coconut.RuntimeError(obj.__name__ + "." + name + " marked with @override but not overriding anything")
+def reveal_type(obj):
+    """Special function to get MyPy to print the type of the given expression.
+    At runtime, reveal_type is the identity function."""
+    return obj
+def reveal_locals():
+    """Special function to get MyPy to print the type of the current locals.
+    At runtime, reveal_locals always returns None."""
+    pass
 _coconut_MatchError, _coconut_count, _coconut_enumerate, _coconut_filter, _coconut_makedata, _coconut_map, _coconut_reiterable, _coconut_reversed, _coconut_starmap, _coconut_tee, _coconut_zip, TYPE_CHECKING, reduce, takewhile, dropwhile = MatchError, count, enumerate, filter, makedata, map, reiterable, reversed, starmap, tee, zip, False, _coconut.functools.reduce, _coconut.itertools.takewhile, _coconut.itertools.dropwhile
